=== modified file 'commit.py'
--- commit.py	2007-10-01 21:41:22 +0000
+++ commit.py	2007-10-01 22:04:43 +0000
@@ -231,7 +231,7 @@
         self._treeview_files.set_model(store)
 
     def _fill_in_diff(self):
-        self._diff_label = gtk.Label(_('Diff for whole tree'))
+        self._diff_label.set_text(_('Diff for whole tree'))
         self._diff_view.set_trees(self._wt, self._basis_tree)
         self._diff_view.show_diff(None)
 
@@ -454,12 +454,13 @@
         self._global_message_text_view.show()
 
     def _on_treeview_files_cursor_changed(self, treeview):
-         treeselection = treeview.get_selection()
-         (model, iter) = treeselection.get_selected()
+        treeselection = treeview.get_selection()
+        (model, iterable) = treeselection.get_selected()
 
-         if iter is not None:
-             selected = model.get_value(iter, 1) # Get the real_path attribute
-             self._diff_view.show_diff([selected])
+        if iterable is not None:
+            path, display_path = model.get(iterable, 1, 3) # Get the real_path attribute
+            self._diff_label.set_text(_('Diff for ') + display_path)
+            self._diff_view.show_diff([path])
 
     @staticmethod
     def _rev_to_pending_info(rev):

=== modified file 'diff.py'
--- diff.py	2007-10-01 18:26:38 +0000
+++ diff.py	2007-10-01 22:04:43 +0000
@@ -213,7 +213,13 @@
 
     def show_diff(self, specific_files):
         s = StringIO()
-        show_diff_trees(self.parent_tree, self.rev_tree, s, specific_files)
+        show_diff_trees(self.parent_tree, self.rev_tree, s, specific_files,
+                        old_label='', new_label='',
+                        # path_encoding=sys.getdefaultencoding()
+                        # The default is utf-8, but we interpret the file
+                        # contents as getdefaultencoding(), so we should
+                        # probably try to make the paths in the same encoding.
+                        )
         self.buffer.set_text(s.getvalue().decode(sys.getdefaultencoding(), 'replace'))
 
 

=== modified file 'tests/test_commit.py'
--- tests/test_commit.py	2007-10-01 21:41:22 +0000
+++ tests/test_commit.py	2007-10-01 22:04:43 +0000
@@ -338,3 +338,37 @@
         self.assertEqual([('a-id', 'a', True, 'a', 'removed'),
                           ('b-id', 'b', True, 'b/', 'removed'),
                          ], values)
+
+    def test_diff_view(self):
+        tree = self.make_branch_and_tree('tree')
+        self.build_tree(['tree/a', 'tree/b'])
+        tree.add(['a', 'b'], ['a-id', 'b-id'])
+        tree.commit('one')
+
+        self.build_tree_contents([('tree/a', 'new contents for a\n')])
+        tree.remove('b')
+
+        dlg = commit.CommitDialog(tree)
+        diff_buffer = dlg._diff_view.buffer
+        text = diff_buffer.get_text(diff_buffer.get_start_iter(),
+                                    diff_buffer.get_end_iter()).splitlines(True)
+
+        self.assertEqual("=== removed file 'b'\n", text[0])
+        self.assertContainsRe(text[1],
+            r"--- b\t\d\d\d\d-\d\d-\d\d \d\d:\d\d:\d\d [+-]\d\d\d\d")
+        self.assertEqual('+++ b\t1970-01-01 00:00:00 +0000\n', text[2])
+        self.assertEqual('@@ -1,1 +0,0 @@\n', text[3])
+        self.assertEqual('-contents of tree/b\n', text[4])
+        self.assertEqual('\n', text[5])
+
+        self.assertEqual("=== modified file 'a'\n", text[6])
+        self.assertContainsRe(text[7],
+            r"--- a\t\d\d\d\d-\d\d-\d\d \d\d:\d\d:\d\d [+-]\d\d\d\d")
+        self.assertContainsRe(text[8],
+            r"\+\+\+ a\t\d\d\d\d-\d\d-\d\d \d\d:\d\d:\d\d [+-]\d\d\d\d")
+        self.assertEqual('@@ -1,1 +1,1 @@\n', text[9])
+        self.assertEqual('-contents of tree/a\n', text[10])
+        self.assertEqual('+new contents for a\n', text[11])
+        self.assertEqual('\n', text[12])
+
+        self.assertEqual('Diff for whole tree', dlg._diff_label.get_text())

